Package 'MSMB'

Title: Data sets for the book 'Modern Statistics for Biology'
Description: Data sets for the book 'Modern Statistics for Modern Biology', S.P. Holmes and W. Huber.
Authors: Wolfgang Huber, Andrzej Oles, Mike Smith
Maintainer: Wolfgang Huber <[email protected]>
License: LGPL
Version: 1.31.0
Built: 2026-06-12 10:43:22 UTC
Source: https://git.bioconductor.org/packages/MSMB

Help Index


Coordinates and cell types in a histopathology slide of a breast cancer patient's lymph node

Description

Coordinates and cell types in a histopathology slide of a breast cancer patient's lymph node.

Usage

data("brcalymphnode")

Format

A data.frame.

Details

This dataset is used as an example in the 'Image data' chapter. See there for more details about it.

Examples

data("brcalymphnode")
   plot(x = brcalymphnode$x, y = brcalymphnode$y, pch=".", col = brcalymphnode$class)

Coordinates of and pairwise distances between hero cities and oblast capitals in Ukraine

Description

This dataset is used as an example in the 'Multivariate methods for heterogeneous data' chapter.

Usage

data("ukraine_dists")
  data("ukraine_coords")

Format

ukraine_dists is an object of S3 class dist. ukraine_coords is a tibble.

Details

The two datasets were constructed using the R code in the file ‘ukraine-dists.R’ in the ‘scripts’ directory of this package. Briefly, the city and place names are hardcoded in the script, coordinates were queried from OpenStreetMap using the geo function in the tidygeocoder, and pairwise geodesic distances computed using the geodist function from the eponymous package.

Examples

data("ukraine_coords")
   plot(x = ukraine_coords$lon, y = ukraine_coords$lat, pch = 16, cex = 0.7, col = "#0057b7", asp = 1 / cos(pi / 180 * 48))
   text(x = ukraine_coords$lon, y = ukraine_coords$lat, labels = ukraine_coords$city, adj = c(0.5, -0.2))